library(plyr)
library(VGAM)
library(ggplot2)
library(pscl)
library(MASS)
library(boot)
library(multcomp)
library(car)
library(ggpubr)
library(imager)
library(survival)
library(ggfortify)
library(ranger)
library(survminer)
library(aod)

all <- read.csv("all.csv", header = TRUE, sep = ",", dec = ".", fill = TRUE)

male <- all[which (all$sex %in% c("Male")),]
malep <- male[which (male$odsource %in% c("Plant material")),]
malehe <- male[which (male$odsource %in% c("Headspace extract")),]

female <- all[which (all$sex %in% c("Mated female")),]
femalep <- female[which (female$odsource %in% c("Plant material")),]
femalehe <- female[which (female$odsource %in% c("Headspace extract")),]


vfemale <- all[which (all$sex %in% c("Virgin female")),]
vfemalep <- vfemale[which (vfemale$odsource %in% c("Plant material")),]
vfemalehe <- vfemale[which (vfemale$odsource %in% c("Headspace extract")),]

# Logestic regression
# Male plant

# Take off
malepT <- malep[which (malep$reachl %in% c("Take off")),]
mod1 <- glm(actual ~ trt, data = malepT, family = "binomial")
Anova(mod1)
summary (glht(mod1, linfct=mcp(trt="Dunnett")))

# 50 cm
malep50 <- malep[which (malep$reachl %in% c("50 cm")),]
mod2 <- glm(actual ~ trt, data = malep50, family = "binomial")
Anova(mod2)
summary (glht(mod2, linfct=mcp(trt="Dunnett")))

# 7 cm
malep7 <- malep[which (malep$reachl %in% c("7 cm")),]
mod3 <- glm(actual ~ trt, data = malep7, family = "binomial")
Anova(mod3)
summary (glht(mod3, linfct=mcp(trt="Dunnett")))

# Land

malepL <- malep[which (malep$reachl %in% c("Land")),]
mod4 <- glm (actual ~ trt, data = malepL, family = "binomial")
Anova(mod4)
summary (glht(mod4, linfct=mcp(trt="Dunnett")))

--------------------------------------------------------------------------
# Male Headspace

# Take off
maleheT <- malehe[which (malehe$reachl %in% c("Take off")),]
mod5 <- glm(actual ~ trt, data = maleheT, family = "binomial")
Anova(mod5)
summary (glht(mod5, linfct=mcp(trt="Dunnett")))

# 50 cm
malehe50 <- malehe[which (malehe$reachl %in% c("50 cm")),]
mod6 <- glm(actual ~ trt, data = malehe50, family = "binomial")
Anova(mod6)
summary (glht(mod6, linfct=mcp(trt="Dunnett")))

# 7 cm
malehe7 <- malehe[which (malehe$reachl %in% c("7 cm")),]
mod7 <- glm(actual ~ trt, data = malehe7, family = "binomial")
Anova(mod7)
summary (glht(mod7, linfct=mcp(trt="Dunnett")))

# Land

maleheL <- malehe[which (malehe$reachl %in% c("Land")),]
mod8 <- glm (actual ~ trt, data = maleheL, family = "binomial")
Anova(mod8)
summary (glht(mod8, linfct=mcp(trt="Dunnett")))

----------------------------------------------------------------------------------
# Mated female plant

# Take off
femalepT <- femalep[which (femalep$reachl %in% c("Take off")),]
mod9 <- glm(actual ~ trt, data = femalepT, family = "binomial")
Anova(mod9)
summary (glht(mod9, linfct=mcp(trt="Dunnett")))

# 50 cm
femalep50 <- femalep[which (femalep$reachl %in% c("50 cm")),]
mod10 <- glm(actual ~ trt, data = femalep50, family = "binomial")
Anova(mod10)
summary (glht(mod10, linfct=mcp(trt="Dunnett")))

# 7 cm
femalep7 <- femalep[which (femalep$reachl %in% c("7 cm")),]
mod11 <- glm(actual ~ trt, data = femalep7, family = "binomial")
Anova(mod11)
summary (glht(mod11, linfct=mcp(trt="Dunnett")))

# Land
femalepL <- femalep[which (femalep$reachl %in% c("Land")),]
mod12 <- glm (actual ~ trt, data = femalepL, family = "binomial")
plot(density(mod12$residuals))
Anova(mod12)
summary (glht(mod12, linfct=mcp(trt="Dunnett")))

----------------------------------------------------------------------------------------
  
# Mated female Headspace
  
# Take off
femaleheT <- femalehe[which (femalehe$reachl %in% c("Take off")),]
mod13 <- glm(actual ~ trt, data = femaleheT, family = "binomial")
Anova(mod13)
summary (glht(mod13, linfct=mcp(trt="Dunnett")))

# 50 cm
femalehe50 <- femalehe[which (femalehe$reachl %in% c("50 cm")),]
mod14 <- glm(actual ~ trt, data = femalehe50, family = "binomial")
Anova(mod14)
summary (glht(mod14, linfct=mcp(trt="Dunnett")))

# 7 cm
femalehe7 <- femalehe[which (femalehe$reachl %in% c("7 cm")),]
mod15 <- glm(actual ~ trt, data = femalehe7, family = "binomial")
Anova(mod15)
summary (glht(mod15, linfct=mcp(trt="Dunnett")))

# Land

femaleheL <- femalehe[which (femalehe$reachl %in% c("Land")),]
mod16 <- glm (actual ~ trt, data = femaleheL, family = "binomial")
Anova(mod16)
summary (glht(mod16, linfct=mcp(trt="Dunnett")))


-------------------------------------------------------------------------------------------
  

# virgin female plant
  
# Take off
vfemalepT <- vfemalep[which (vfemalep$reachl %in% c("Take off")),]
mod17 <- glm(actual ~ trt, data = vfemalepT, family = "binomial")
Anova(mod17)
summary (glht(mod17, linfct=mcp(trt="Dunnett")))

# 50 cm
vfemalep50 <- vfemalep[which (vfemalep$reachl %in% c("50 cm")),]
mod18 <- glm(actual ~ trt, data = vfemalep50, family = "binomial")
Anova(mod18)
summary (glht(mod18, linfct=mcp(trt="Dunnett")))

# 7 cm
vfemalep7 <- vfemalep[which (vfemalep$reachl %in% c("7 cm")),]
mod19 <- glm(actual ~ trt, data = vfemalep7, family = "binomial")
Anova(mod19)
summary (glht(mod19, linfct=mcp(trt="Dunnett")))

# Land
vfemalepL <- vfemalep[which (vfemalep$reachl %in% c("Land")),]
mod20 <- glm (actual ~ trt, data = vfemalepL, family = "binomial")
Anova(mod20)
summary (glht(mod20, linfct=mcp(trt="Dunnett")))

  
-----------------------------------------------------------------------------------------------
  
# virgin female Headspace
  
# Take off
vfemaleheT <- vfemalehe[which (vfemalehe$reachl %in% c("Take off")),]
mod21 <- glm(actual ~ trt, data = vfemaleheT, family = "binomial")
Anova(mod21)
summary (glht(mod21, linfct=mcp(trt="Dunnett")))

# 50 cm
vfemalehe50 <- vfemalehe[which (vfemalehe$reachl %in% c("50 cm")),]
mod22 <- glm(actual ~ trt, data = vfemalehe50, family = "binomial")
Anova(mod22)
summary (glht(mod22, linfct=mcp(trt="Dunnett")))

# 7 cm
vfemalehe7 <- vfemalehe[which (vfemalehe$reachl %in% c("7 cm")),]
mod23 <- glm(actual ~ trt, data = vfemalehe7, family = "binomial")
Anova(mod23)
summary (glht(mod23, linfct=mcp(trt="Dunnett")))

# Land

vfemaleheL <- vfemalehe[which (vfemalehe$reachl %in% c("Land")),]
mod24 <- glm (actual ~ trt, data = vfemaleheL, family = "binomial")
Anova(mod24)
summary (glht(mod24, linfct=mcp(trt="Dunnett")))



/////////////////////////////////////////////////////////////////////////////////////////////////////
  
  # Kaplan_Meier 
# Male Plant  
  
  # Pistachio
malepp<-malep[which(malep$trt %in% c("Pistachio","Blank")),]
km_fit <- survfit(Surv(rch, stat) ~ trt, data=malepp)
ggsurvplot(km_fit, data = malepp, pval = TRUE, xlab="", ylab= "Reached")

  # Cracked pom
malepcp<-malep[which(malep$trt %in% c("Cracked pom","Blank")),]
km_fit <- survfit(Surv(rch, stat) ~ trt, data=malepcp)
ggsurvplot(km_fit, data = malepcp, pval = TRUE, xlab="", ylab= "Reached")

# Uncracked pom
malepup<-malep[which(malep$trt %in% c("Uncracked pom","Blank")),]
km_fit <- survfit(Surv(rch, stat) ~ trt, data=malepup)
ggsurvplot(km_fit, data = malepup, pval = TRUE, xlab="", ylab= "Reached")
  
#Unripe pom 
malepurp<-malep[which(malep$trt %in% c("Unripe pom","Blank")),]
km_fit <- survfit(Surv(rch, stat) ~ trt, data=malepurp)
ggsurvplot(km_fit, data = malepurp, pval = TRUE, xlab="", ylab= "Reached")

#Flower pom 
malepf<-malep[which(malep$trt %in% c("Flower pom","Blank")),]
km_fit <- survfit(Surv(rch, stat) ~ trt, data=malepf)
ggsurvplot(km_fit, data = malepf, pval = TRUE, xlab="", ylab= "Reached")

-------------------------------------
# Male Headspace extract  

# Pistachio HE
malehep<-malehe[which(malehe$trt %in% c("Pistachio HE","Blank")),]
km_fit <- survfit(Surv(rch, stat) ~ trt, data=malehep)
ggsurvplot(km_fit, data = malehep, pval = TRUE, xlab="", ylab= "Reached")

# Cracked pom HE
malehecp<-malehe[which(malehe$trt %in% c("Cracked pom HE","Blank")),]
km_fit <- survfit(Surv(rch, stat) ~ trt, data=malehecp)
ggsurvplot(km_fit, data = malehecp, pval = TRUE, xlab="", ylab= "Reached")

-----------------------------------------------------
  
 
  # Mated female Plant  
  
  # Pistachio
femalepp<-femalep[which(femalep$trt %in% c("Pistachio","Blank")),]
km_fit <- survfit(Surv(rch, stat) ~ trt, data=femalepp)
ggsurvplot(km_fit, data = femalepp, pval = TRUE, xlab="", ylab= "Reached")

# Cracked pom
femalepcp<-femalep[which(femalep$trt %in% c("Cracked pom","Blank")),]
km_fit <- survfit(Surv(rch, stat) ~ trt, data=femalepcp)
ggsurvplot(km_fit, data = femalepcp, pval = TRUE, xlab="", ylab= "Reached")

# Uncracked pom
femalepup<-femalep[which(femalep$trt %in% c("Uncracked pom","Blank")),]
km_fit <- survfit(Surv(rch, stat) ~ trt, data=femalepup)
ggsurvplot(km_fit, data = femalepup, pval = TRUE, xlab="", ylab= "Reached")

#Unripe pom 
femalepurp<-femalep[which(femalep$trt %in% c("Unripe pom","Blank")),]
km_fit <- survfit(Surv(rch, stat) ~ trt, data=femalepurp)
ggsurvplot(km_fit, data = femalepurp, pval = TRUE, xlab="", ylab= "Reached")

#Flower pom 
femalepf<-femalep[which(femalep$trt %in% c("Flower pom","Blank")),]
km_fit <- survfit(Surv(rch, stat) ~ trt, data=femalepf)
ggsurvplot(km_fit, data = femalepf, pval = TRUE, xlab="", ylab= "Reached")

-------------------------------------
  # Mated female Headspace extract  
  
  # Pistachio HE
femalehep<-femalehe[which(femalehe$trt %in% c("Pistachio HE","Blank")),]
km_fit <- survfit(Surv(rch, stat) ~ trt, data=femalehep)
ggsurvplot(km_fit, data = femalehep, pval = TRUE, xlab="", ylab= "Reached")

# Cracked pom HE
femalehecp<-femalehe[which(femalehe$trt %in% c("Cracked pom HE","Blank")),]
km_fit <- survfit(Surv(rch, stat) ~ trt, data=femalehecp)
ggsurvplot(km_fit, data = femalehecp, pval = TRUE, xlab="", ylab= "Reached")

-----------------------------------------------------
# Virgin female Plant  
  
# Pistachio
# vfemalepp<-vfemalep[which(vfemalep$trt %in% c("Pistachio","Blank")),]
# km_fit <- survfit(Surv(rch, stat) ~ trt, data=vfemalepp)
# ggsurvplot(km_fit, data = vfemalepp, pval = TRUE, xlab="", ylab= "Reached")

# Cracked pom
vfemalepcp<-vfemalep[which(vfemalep$trt %in% c("Cracked pom","Blank")),]
km_fit <- survfit(Surv(rch, stat) ~ trt, data=vfemalepcp)
ggsurvplot(km_fit, data = vfemalepcp, pval = TRUE, xlab="", ylab= "Reached")

# Uncracked pom
vfemalepup<-vfemalep[which(vfemalep$trt %in% c("Uncracked pom","Blank")),]
km_fit <- survfit(Surv(rch, stat) ~ trt, data=vfemalepup)
ggsurvplot(km_fit, data = vfemalepup, pval = TRUE, xlab="", ylab= "Reached")

#Unripe pom 
vfemalepurp<-vfemalep[which(vfemalep$trt %in% c("Unripe pom","Blank")),]
km_fit <- survfit(Surv(rch, stat) ~ trt, data=vfemalepurp)
ggsurvplot(km_fit, data = vfemalepurp, pval = TRUE, xlab="", ylab= "Reached")

#Flower pom 
vfemalepf<-vfemalep[which(vfemalep$trt %in% c("Flower pom","Blank")),]
km_fit <- survfit(Surv(rch, stat) ~ trt, data=vfemalepf)
ggsurvplot(km_fit, data = vfemalepf, pval = TRUE, xlab="", ylab= "Reached")

-------------------------------------
  # vfemale Headspace extract  
  
  # Pistachio HE
vfemalehep<-vfemalehe[which(vfemalehe$trt %in% c("Pistachio HE","Blank")),]
km_fit <- survfit(Surv(rch, stat) ~ trt, data=vfemalehep)
ggsurvplot(km_fit, data = vfemalehep, pval = TRUE, xlab="", ylab= "Reached")

# Cracked pom HE
vfemalehecp<-vfemalehe[which(vfemalehe$trt %in% c("Cracked pom HE","Blank")),]
km_fit <- survfit(Surv(rch, stat) ~ trt, data=vfemalehecp)
ggsurvplot(km_fit, data = vfemalehecp, pval = TRUE, xlab="", ylab= "Reached")

-----------------------------------------------------
  
  
  
  

\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\


# Relative amount of Beta-caryophyllene in the plant materials

car <- read.csv("Ccaryo.csv", header = TRUE, sep = ",", dec = ".", fill = TRUE)

Glm <- glm(rel~trt, data=car, family = Gamma)
Anova(Glm)
plot(density(Glm$residuals))

#  AIC(Glm2)
# 1 - pchisq(summary(Glm2)$deviance, summary(Glm2)$df.residual)
# # # OK!
# plot(density(Glm2$residuals))


p <- glht(Glm, linfct = mcp(trt = "Tukey"))
# summary(p)          # standard display
p.cld <- cld(p)   # letter-based display
cld(p)
  
\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\

# Model analysis
caryo <- Ovi [which (Ovi$trt %in% c("Hexane (control)", "Beta-caryophyllene")),]
cis3 <- Ovi [which (Ovi$trt %in% c("Hexane (control)", "Cis-3-hexen-1-ol")),]


modc <- glm(data=caryo, tot~consl+date , family = poisson) 
densityPlot(modc$residuals)
Anova (modc)
summary (glht(modc, linfct=mcp(consl="Dunnett")))


p <- glht(modc, linfct = mcp(consl = "Tukey"))
# summary(p)          # standard display
p.cld <- cld(p)   # letter-based display
cld(p)


modcis <- glm(data=cis3, tot~consl + date, family = poisson) 
Anova (modcis)
densityPlot(modcis$residuals)
summary (glht(modcis, linfct=mcp(consl="Dunnett")))

p <- glht(modcis, linfct = mcp(consl = "Tukey"))
# summary(p)          # standard display
p.cld <- cld(p)   # letter-based display
cld(p)
